@@ -1,12 +1,11 @@
-// make tabular inlines sortable
+// make tabular- and stacked inlines sortable
 jQuery(function($) {
 	$('div.inline-group').each(function() {
 		var default_order_field = $(this).nextUntil('div.default_order_field').next().attr('default_order_field');
 		var order_input_field = 'input[name$="' + default_order_field + '"]';
-		$(this).find(order_input_field).each(function() {
-			$(this).clone().attr('type', 'hidden').insertAfter($(this)).prev().remove();
-		});
-		$(this).find('div.tabular table').sortable({
+		// tabluar inlines
+		var tabular_inlines = $(this).find('div.tabular table');
+		tabular_inlines.sortable({
 			items: 'tr.form-row.has_original',
 			axis: 'y',
 			scroll: true,
@@ -22,5 +21,22 @@ jQuery(function($) {
 				});
 			}
 		});
+		if (tabular_inlines.length)
+			return true;
+		// else, try with stacked inlines
+		$(this).sortable({
+			handle: 'h3',
+			items: 'div.inline-related.has_original',
+			axis: 'y',
+			scroll: true,
+			cursor: 'ns-resize',
+			containment: $(this),
+			stop: function(event, dragged_rows) {
+				var $result_list = $(this);
+				$result_list.find('div.inline-related.has_original').each(function(index) {
+					$(this).find(order_input_field).val(index + 1);
+				});
+			}
+		});
 	});
 });
